%define name	timezone
%define epoch	6
%define version	2008f
%define release	%mkrel 1

%define tzdata_version %{version}
%define tzcode_version 2008e

# the zic(8) and zdump(8) manpages are already in man-pages
%define build_manpages 0

# don't use new TZ format yet (zic & zdump from glibc 2.4.90)
# XXX update after 2007.1 release, for all past releases too?
%define new_format 0
%if %{mdkversion} > 200710
%define new_format 1
%endif

# define glibc mininmal version which drops /etc/localtime
# XXX update for older distributions here
%if %{mdkversion} >= 200710
%define glibc_min_version 6:2.4-%{mkrel 8}
%endif

Summary:	Timezone data
Name:		%{name}
Epoch:		%{epoch}
Version:	%{version}
Release:	%{release}
License:	GPL
Group:		System/Base
Conflicts:	glibc < 6:2.2.5-6mdk
Source0:	tzdata-base-0.tar.bz2
Source1:	ftp://elsie.nci.nih.gov/pub/tzdata%{tzdata_version}.tar.gz
Source2:	ftp://elsie.nci.nih.gov/pub/tzcode%{tzcode_version}.tar.gz
Source3:	update-localtime.sh
Patch0:		tzdata-mdvconfig.patch
Patch1:		tzdata-extra-tz-links.patch
Patch2:		tzdata-tzcode2006a.patch
Patch3:		tzdata-brazil-decree-6558.patch
BuildRequires:	gawk, perl
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
This package contains data files with rules for various timezones
around the world.

%prep
%setup -q -n tzdata
mkdir tzdata%{tzdata_version}
tar xzf %{SOURCE1} -C tzdata%{tzdata_version}
mkdir tzcode%{tzcode_version}
tar xzf %{SOURCE2} -C tzcode%{tzcode_version}

%patch0 -p1 -b .mdvconfig
%patch1 -p1 -b .extra-tz-links
%if ! %{new_format}
cd tzcode%{tzcode_version}
%patch2 -p2 -b .tzcode2006a
cd ..
%endif
%patch3 -p1 -b .brazil-decree-6558

ln -s Makeconfig.in Makeconfig
cat > config.mk << EOF
objpfx = `pwd`/obj/
sbindir = %{_sbindir}
datadir = %{_datadir}
install_root = %{buildroot}
sysdep-CFLAGS = %{optflags}
EOF

# Create zone.info entries for deprecated zone names (#40184)
pushd tzdata%{tzdata_version}
	chmod +w zone.tab
	echo "# zone info for backward zone names" >> zone.tab
	cat backward | grep Link | while read link curr old; do
		if [ -z "$curr" -o -z "$old" ]; then
			echo "Error processing backward entry for zone.tab"
			exit 1
		fi
		cat zone.tab | grep -v '^#' | grep "$curr" | \
		    while read l; do
			if [ "`echo \"$l\" | awk 'BEGIN { FS = \"[\t]\" } \
			       { print $3 }'`" = "$curr" ]; then
				echo "$l" | sed "s|$curr|$old|" >> zone.tab \
					|| echo ERROR >> zone.tab
			else
				echo ERROR >> zone.tab
			fi
		done
	done
popd
if grep -q "^ERROR" tzdata%{tzdata_version}/zone.tab; then
	echo "Error adding backward entries to zone.tab"
	exit 1
fi

%build
%make
grep -v tz-art.htm tzcode%{tzcode_version}/tz-link.htm > tzcode%{tzcode_version}/tz-link.html

%install
rm -rf $RPM_BUILD_ROOT

make install

# nuke unpackaged files
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/localtime

# install man pages
%if %{build_manpages}
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man8
for f in zic zdump; do
install -m 644 tzcode*/$f.8 $RPM_BUILD_ROOT%{_mandir}/man8/
done
%endif

# install update-localtime script
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
install -m 755 %{SOURCE3} $RPM_BUILD_ROOT%{_sbindir}/update-localtime
perl -pi -e 's|\@datadir\@|%{_datadir}|;' \
	 -e 's|\@sysconfdir\@|%{_sysconfdir}|' \
	$RPM_BUILD_ROOT%{_sbindir}/update-localtime

%check
echo ====================TESTING=========================
make check
echo ====================TESTING END=====================

%post -p %{_sbindir}/update-localtime

# XXX next glibc updates are expected to remove /etc/localtime
%triggerpostun -- glibc %{?glibc_min_version:< %{glibc_min_version}}
if [ ! -f %{_sysconfdir}/localtime ]; then
  %{_sbindir}/update-localtime
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc tzcode%{tzcode_version}/README
%doc tzcode%{tzcode_version}/Theory
%doc tzcode%{tzcode_version}/tz-link.html
%{_sbindir}/zdump
%{_sbindir}/zic
%{_sbindir}/update-localtime
%if %{build_manpages}
%{_mandir}/man8/zdump.8*
%{_mandir}/man8/zic.8*
%endif
%dir %{_datadir}/zoneinfo
%{_datadir}/zoneinfo/*








%changelog
* Thu Sep 18 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6:2008f-1mdv2007.1
+ Revision: 285581
- Updated tzdata to 2008f
- Use now fixed Brazil rule for daylight savings time (decree 6558),
  patch based on a previous one by Frederico A. C. Neves

* Thu Aug 28 2008 Vincent Danen <vdanen@mandriva.com> 6:2008e-1.1mdv2007.1
+ Revision: 276972
- build for updates

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Updated tzcode/tzdata to 2008e release.

* Thu Jul 17 2008 Gustavo De Nardin <gustavodn@mandriva.com> 2008d-1.1mdv2007.1
+ Revision: 236655
- build for updates

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Updated tzdata to 2008d
    - Make sure we don't add blank lines to zone.tab to prevent bad parsers
      from crashing (also it isn't clear if blank lines is really allowed),
      as example see bug #41218.
    - Updated to 2008c
    - Rediffed tzdata-extra-tz-links.patch
    - Create zone.info entries for deprecated zone names (#40184).
    - Updated to 2008b.
    - Updated to 2008a.
    - Redid tzdata-tzcode2006a.patch, update for 2008a code changes.
    - Rediffed tzdata-extra-tz-links.patch
    - update-localtime.sh: make sure /etc/localtime has the right
      permissions after copy using install -m (#30045).
    - Updated to 2007k.
    - Redid tzdata-tzcode2006a.patch, update for 2007k code changes.
    - Rediffed tzdata-extra-tz-links.patch
    - Updated to 2007j.
    - Redid tzdata-tzcode2006a.patch, revert some code changes from 2007j
      version.
    - Updated tzdata to 2007i.
    - Rediffed tzdata-extra-tz-links patch.
    - Updated to 2007h.
    - Redid tzdata-tzcode2006a patch.
    - Fixed tzdata-extra-tz-links patch to apply against tzdata2007f.
    - Updated to 2007f.

  + Andreas Hasenack <andreas@mandriva.com>
    - branched cooker into 2007.1 (will have to revert some recent changes)


* Wed Mar 14 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2007c-2mdv2007.1
+ Revision: 143844
- fix triggers

* Wed Mar 07 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 6:2007c-1mdv2007.1
+ Revision: 134361
- use upstream tz{data,code} 2007c

* Wed Mar 07 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2007c-1mdv
- use upstream tz{data,code} 2007c

